[−][src]Struct mongodb_cwal::topology::server::Server
Holds status and connection information about a single server.
Fields
host: HostHost connection details.
description: Arc<RwLock<ServerDescription>>Monitored server information.
Implementations
impl Server[src]
pub fn new(
client: Client,
host: Host,
top_description: Arc<RwLock<TopologyDescription>>,
run_monitor: bool,
connector: StreamConnector,
pool_size: Option<usize>,
idle_timeout: Option<Duration>
) -> Server[src]
client: Client,
host: Host,
top_description: Arc<RwLock<TopologyDescription>>,
run_monitor: bool,
connector: StreamConnector,
pool_size: Option<usize>,
idle_timeout: Option<Duration>
) -> Server
Returns a new server with the given host, initializing a new connection pool and monitor.
pub fn acquire_stream(&self, client: Client) -> Result<PooledStream>[src]
Returns a server stream from the connection pool.
pub fn request_update(&self)[src]
Request an update from the monitor on the server status.